@@ -13,7 +13,7 @@ use strict;
 use 5.008001;
 use base 'URI::Nested';
 use URI::_db;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 sub prefix       { 'db' }
 sub nested_class { 'URI::_db' }
@@ -273,9 +273,11 @@ Returns a L<DBI> DSN appropriate for use in a call to C<< DBI->connect >>. The
 attributes will usually be pulled from the URI host name, port, and database
 name, as well as the query parameters. If no driver is known for the URI, the
 C<dbi:$driver:> part of the DSN will be omitted, in which case you can use the
-C<$DBI_DRIVER> environment variable to identify an appropriate driver.
-Otherwise, each database URI does its best to create a valid DBI DSN. Some
-examples:
+C<$DBI_DRIVER> environment variable to identify an appropriate driver. If the
+URI supports multiple drivers, pass the name of the one you want to
+C<dbi_dsn()>. Currently only URI::myssql supports alternate drivers, ADO,
+ODBC, or Sybase. Otherwise, each database URI does its best to create a valid
+DBI DSN. Some examples:
 
   | URI                                  | DSN                                              |
   |--------------------------------------+--------------------------------------------------|
